@@ -20,6 +20,8 @@
 
 """
 a (very basic) script to collect all text files in a directory, markovify them and output a user-specified number of sentences to a text file.
+
+TODO: handle non-utf-8 encoded files.
 """
      
 import markovify
@@ -53,12 +55,14 @@ def main():
             if filename.endswith(('.txt', '.org', '.md')):
                 matches.append(os.path.join(root, filename))
 
-    # concatenate the files into batchfile.txt:
-    batchfile = os.path.dirname(args.indir) + os.path.sep + 'batchfile.txt' # SEEMS like it works?
+    # place batchfile.txt in user-given directory:
+    batchfile = os.path.dirname(args.indir) + os.path.sep + 'batchfile.txt'
 
-    with open(batchfile, 'w') as outfile:    
+    # concatenate the files into batchfile.txt:
+    ###NB: trying to avoid encoding error here:
+    with open(batchfile, 'w', encoding="utf-8") as outfile:    
         for fname in matches:
-            with open(fname) as infile:
+            with open(fname, encoding="latin-1") as infile:
                 outfile.write(infile.read())
 
     # Get raw text from batchfile as string.
@@ -66,7 +70,6 @@ def main():
         text = f.read()
     
     # Build the model:
-    # NB: this errors if infile is EMPTY:
     text_model = markovify.Text(text, state_size=args.statesize)
 
     # Print -n number of randomly-generated sentences
